@@ -382,13 +382,23 @@ impl<'g> TestList<'g> {
         // <test name>: test
         // ...
 
-        list_output.lines().map(move |line| {
-            line.strip_suffix(": test").ok_or_else(|| {
+        list_output.lines().filter_map(move |line| {
+            if line.ends_with(": benchmark") {
+                // These lines are produced by the default Rust benchmark harness (#[bench]).
+                // Ignore them.
+                return None;
+            }
+
+            let res = line.strip_suffix(": test").ok_or_else(|| {
                 ParseTestListError::parse_line(
-                    format!("line '{}' did not end with the string ': test'", line),
+                    format!(
+                        "line '{}' did not end with the string ': test' or ': benchmark'",
+                        line
+                    ),
                     list_output,
                 )
-            })
+            });
+            Some(res)
         })
     }
 
@@ -406,7 +416,7 @@ impl<'g> TestList<'g> {
                 writeln!(indented, "(no tests)")?;
             } else {
                 for (name, info) in &info.testcases {
-                    write_test_name(name, self.styles.test_name, &mut indented)?;
+                    write_test_name(name, &self.styles, &mut indented)?;
                     if !info.filter_match.is_match() {
                         write!(indented, " (skipped)")?;
                     }
@@ -542,6 +552,7 @@ impl<'a> TestInstance<'a> {
 pub(super) struct Styles {
     pub(super) binary_id: Style,
     pub(super) test_name: Style,
+    pub(super) module_path: Style,
     field: Style,
 }
 
@@ -550,6 +561,7 @@ impl Styles {
         self.binary_id = Style::new().magenta().bold();
         self.test_name = Style::new().blue().bold();
         self.field = Style::new().yellow().bold();
+        self.module_path = Style::new().cyan();
     }
 }
 
@@ -567,11 +579,14 @@ mod tests {
 
     #[test]
     fn test_parse() {
+        // Lines ending in ': benchmark' (output by the default Rust bencher) should be skipped.
         let non_ignored_output = indoc! {"
             tests::foo::test_bar: test
             tests::baz::test_quux: test
+            benches::should_be_skipped: benchmark
         "};
         let ignored_output = indoc! {"
+            benches::ignored_should_be_skipped: benchmark
             tests::ignored::test_bar: test
             tests::baz::test_ignored: test
         "};
